@@ -150,6 +150,9 @@ void AddAccountWizard::back()
 		// removePage() already goes back to previous page, no back() needed
 	}
 	KAssistantDialog::back();
+
+	adjustSize();
+	setMinimumSize(sizeHint());
 }
 
 void AddAccountWizard::next()
@@ -201,6 +204,8 @@ void AddAccountWizard::next()
 		KAssistantDialog::next();
 	}
 
+	adjustSize();
+	setMinimumSize(sizeHint());
 }
 
 void AddAccountWizard::accept()
